@@ -7,7 +7,7 @@ package IO::Async::MergePoint;
 
 use strict;
 
-our $VERSION = '0.16';
+our $VERSION = '0.17';
 
 use Carp;
 
@@ -53,7 +53,7 @@ A merge point maintains a set of outstanding operations it is waiting on;
 these are arbitrary string values provided at the object's construction. Each
 time the C<done()> method is called, the named item is marked as being
 complete. When all of the required items are so marked, the C<on_finished>
-callback is invoked.
+continuation is invoked.
 
 When an item is marked as complete, a value can also be provided, which would
 contain the results of that step. The C<on_finished> callback is passed a hash
@@ -79,17 +79,18 @@ not significant.
 
 =item on_finished => CODE
 
-CODE reference to the handler for when the merge point becomes ready.
+CODE reference to the continuation for when the merge point becomes ready.
 
 =back
 
-The C<on_finished> handler will be called when every key in the C<needs> list
-has been notified by the C<done()> method. It will be called as
+The C<on_finished> continuation will be called when every key in the C<needs>
+list has been notified by the C<done()> method. It will be called as
 
  $on_finished->( %items )
 
 where the C<%items> hash will contain the item names that were waited on, and
-the values passed to the C<done()> method for each one.
+the values passed to the C<done()> method for each one. Note that this is
+passed as a list, not as a HASH reference.
 
 =cut
 
@@ -120,10 +121,10 @@ sub new
 =head2 $merge->done( $item, $value )
 
 This method informs the merge point that the C<$item> is now ready, and
-passes it a value to store, to be passed into the C<on_finished> callback. If
-this call gives the final remaining item being waited for, the C<on_finished>
-callback is called within it, and the method will not return until it has
-completed.
+passes it a value to store, to be passed into the C<on_finished> continuation.
+If this call gives the final remaining item being waited for, the
+C<on_finished> continuation is called within it, and the method will not
+return until it has completed.
 
 =cut
 
